DOMAIN = 'duofern'
DUOFERN_COMPONENTS = ['cover', 'light', 'binary_sensor']
CONF_SERIAL_PORT = 'serial_port'
CONF_CODE = 'code'
